<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8" />
<meta name="viewport" content="width=device-width" />
<title>{% block title %}Test{% endblock %}</title>
</head>
<body>
{% block content %}{% endblock %}

<p>— {% block author %}Anonymous{% endblock %}</p>
</body>
</html>