# -*- coding: utf-8 -*-
"""
# Clay

A rapid prototyping tool

------------
Copyright © 2011 by [Lúcuma labs] (http://lucumalabs.com).  
See `AUTHORS.md` for more details.  
License: [MIT License] (http://www.opensource.org/licenses/mit-license.php).

"""
from .core import *


__version__ = '1.0.9'
