@import url(http://fonts.googleapis.com/css?family=Pacifico);

body {
font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
font-size: 1.6em;
line-height: 1.5;
color: #333;
background: #fefefe;
text-align: center;
}

h1 {
font-family: 'Pacifico', Georgia, serif;
font-size: 2em;
font-weight: normal;
color: #a3312d;
letter-spacing: -1px;
line-height: 1;
margin: 110px 0 50px;
border: 20px;
}

a, a:visited {
color: #a3312d;
border-bottom: 1px dotted;
text-decoration: none;
}

a:hover, a:focus, a:active {
color: #932c28;
border-bottom: 2px solid;
margin-bottom: -1px;
}

.✓ {
margin-top: 90px;
padding: 5px 0;
font-size: 12px;
color: #999;
}